# nssm

Non-Sucking Service Manager — install any Windows executable as a persistent service. Uses bundled nssm.exe from C:/USB/system/nssm/win64/.

## Structure

- `schema.json`: Interface
- `tool.py`: CLI
- worker.py: Background
